==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/zh/lang.php <==
<?php
/**
 * english language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author ZDYX <zhangduyixiong@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
 * @author George Sheraton guxd@163.com
 */
$lang['menu']                  = '插件管理器';
$lang['download']              = '下载并安装新的插件';
$lang['manage']                = '已安装的插件';
$lang['btn_info']              = '信息';
$lang['btn_update']            = '升级';
$lang['btn_delete']            = '删除';
$lang['btn_settings']          = '设置';
$lang['btn_download']          = '下载';
$lang['btn_enable']            = '保存';
$lang['url']                   = 'URL';
$lang['installed']             = '已安装：';
$lang['lastupdate']            = '最后更新于：';
$lang['source']                = '来源：';
$lang['unknown']               = '未知';
$lang['updating']              = '正在升级...';
$lang['updated']               = '插件 %s 升级成功';
$lang['updates']               = '下列插件升级成功：';
$lang['update_none']           = '未找到更新。';
$lang['deleting']              = '正在删除...';
$lang['deleted']               = '插件 %s 已删除';
$lang['downloading']           = '正在下载...';
$lang['downloaded']            = '插件 %s 安装成功';
$lang['downloads']             = '下列插件安装成功：';
$lang['download_none']         = '未找到插件，或下载和安装过程中出现了未知错误。';
$lang['plugin']                = '插件：';
$lang['components']            = '组件';
$lang['noinfo']                = '该插件没有任何信息，有可能是无效插件。';
$lang['name']                  = '名称：';
$lang['date']                  = '日期：';
$lang['type']                  = '类别：';
$lang['desc']                  = '描述：';
$lang['author']                = '作者：';
$lang['www']                   = '网址：';
$lang['error']                 = '产生了未知错误。';
$lang['error_download']        = '无法下载插件：%s';
$lang['error_badurl']          = 'URL 可能有问题 - 从 URL 中无法得知文件名';
$lang['error_dircreate']       = '无法创建用于接收下载文件的';
$lang['error_decompress']      = '插件管理器无法解压下载的文件。这可能是由于下载出现错误，遇到这种情况，请您再次尝试;或者是压缩格式无法识别，遇到这种情况，您需要手动下载并安装该插件。';
$lang['error_copy']            = '尝试安装插件 <em>%s</em> 的相关文件时产生一个复制错误：磁盘空间已满或文件访问权限错误。这可能是由于一个安装了一部分的插件，并使得您的维基系统不稳定。';
$lang['error_delete']          = '尝试删除插件 <em>%s</em> 时产生一个错误。最有可能的情况是文件或路径的访问权限不够';
$lang['enabled']               = '%s 插件开';
$lang['notenabled']            = '%s插件打开失败，请检查文件权限。';
$lang['disabled']              = '%s 插件关';
$lang['notdisabled']           = '%s插件关闭失败，请检查文件权限。';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/zh/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author ZDYX <zhangduyixiong@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
 * @author George Sheraton guxd@163.com
 * @author Simon zhan <simonzhan@21cn.com>
 * @author mr.jinyi@gmail.com
 * @author ben <ben@livetom.com>
 * @author lainme <lainme993@gmail.com>
 * @author caii <zhoucaiqi@gmail.com>
 * @author Hiphen Lee <jacob.b.leung@gmail.com>
 * @author caii, patent agent in China <zhoucaiqi@gmail.com>
 * @author lainme993@gmail.com
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author anjianshi <anjianshi@gmail.com>
 */
$lang['menu']                  = '插件管理器';
$lang['download']              = '下载并安装新的插件';
$lang['manage']                = '已安装的插件';
$lang['btn_info']              = '信息';
$lang['btn_update']            = '升级';
$lang['btn_delete']            = '删除';
$lang['btn_settings']          = '设置';
$lang['btn_download']          = '下载';
$lang['btn_enable']            = '保存';
$lang['url']                   = 'URL';
$lang['installed']             = '安装时间：';
$lang['lastupdate']            = '最后更新于：';
$lang['source']                = '来源：';
$lang['unknown']               = '未知';
$lang['updating']              = '正在升级...';
$lang['updated']               = '插件 %s 升级成功';
$lang['updates']               = '下列插件升级成功：';
$lang['update_none']           = '未找到更新。';
$lang['deleting']              = '正在删除...';
$lang['deleted']               = '插件 %s 已删除';
$lang['downloading']           = '正在下载...';
$lang['downloaded']            = '插件 %s 安装成功';
$lang['downloads']             = '下列插件安装成功：';
$lang['download_none']         = '未找到插件，或下载和安装过程中出现了未知错误。';
$lang['plugin']                = '插件：';
$lang['components']            = '组件';
$lang['noinfo']                = '该插件没有任何信息，有可能是无效插件。';
$lang['name']                  = '名称：';
$lang['date']                  = '日期：';
$lang['type']                  = '类别：';
$lang['desc']                  = '描述：';
$lang['author']                = '作者：';
$lang['www']                   = '网址：';
$lang['error']                 = '产生了未知错误。';
$lang['error_download']        = '无法下载插件：%s';
$lang['error_badurl']          = 'URL 可能有问题 - 从 URL 中无法得知文件名';
$lang['error_dircreate']       = '无法创建用于接收下载文件的';
$lang['error_decompress']      = '插件管理器无法解压下载的文件。这可能是由于下载出现错误，遇到这种情况，请您再次尝试;或者是压缩格式无法识别，遇到这种情况，您需要手动下载并安装该插件。';
$lang['error_copy']            = '尝试安装插件 <em>%s</em> 的相关文件时产生一个复制错误：磁盘空间已满或文件访问权限错误。这可能是由于一个安装了一部分的插件，并使得您的维基系统不稳定。';
$lang['error_delete']          = '尝试删除插件 <em>%s</em> 时产生一个错误。最有可能的情况是文件或路径的访问权限不够';
$lang['enabled']               = '%s 插件启用';
$lang['notenabled']            = '%s插件启用失败，请检查文件权限。';
$lang['disabled']              = '%s 插件禁用';
$lang['notdisabled']           = '%s插件禁用失败，请检查文件权限。';
$lang['packageinstalled']      = '插件  (%d 插件: %s) 已成功安装。';
